+++
title = "Interface model"
weight = 11
+++

# Rough interface models

### Interface model

The mathematical model for one interface must be specified through one of

```python
ba.K_CorrelationModel
ba.LinearGrowthModel
```

##### K correlation model

```python
ba.K_CorrelationModel(sigma, hurst, lateral_corr_length, max_spatial_freq=0.5)
```

where
- `sigma` is the root-mean-square amptitude of out-of-plane (transversal) fluctuations,
- `hurst` is a fractal exponent `H` with `0<H<1`,
- `lateral_corr_length` is the lateral (in-plane) correlation length,
- `max_spatial_freq` is a cut-off.

This is the model of [Palasantzas 1993](https://doi-org.eaccess.tum.edu/10.1103/PhysRevB.48.14472).
It adds a cut-off to the fractal roughness model of
  [Sinha 1988](https://doi-org.eaccess.tum.edu/10.1103/PhysRevB.38.2297).

##### Linear growth model

```python
ba.LinearGrowthModel(particle_volume, damp1, damp2, damp3, damp4, max_spatial_freq=0.5)
```

This is the model described by [Stearns 1993](https://doi.org/10.1063/1.109593)
and extended by [Stearns and Gullikson 2000](https://doi.org/10.1016/S0921-4526(99)01897-9).
